pywws.YoWindow — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.YoWindow

Génére un fichier XML YoWindow.

    usage: python -m pywws.YoWindow [options] data_dir output_file
    options are:
     -h or --help     display this help
     -v or --verbose  increase amount of reassuring messages
    data_dir is the root directory of the weather data
    output_file is the YoWindow XML file to be written

Fonctions

`main`([argv]) |

Classes

`YoWindow`(calib_data) | Classe pour écrire un fichier XML YoWindow.

class `pywws.YoWindow.` `YoWindow`(calib_data)

  Classe pour écrire un fichier XML YoWindow. Pour voir les spécifications du fichier http://yowindow.com/doc/yowindow_pws_format.xml

  `write_file`(file_name, data=None)

`pywws.YoWindow.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »